@@ -1,6 +1,3 @@
-
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -48,7 +45,7 @@ class NotePixmapFactory;
 
 class KeySignatureDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
