@@ -140,41 +140,41 @@ TransportDialog::TransportDialog(TQWidget *parent,
     m_midiOutTimer = new TQTimer(this);
     m_clearMetronomeTimer = new TQTimer(this);
 
-    connect(m_midiInTimer, TQT_SIGNAL(timeout()),
-            TQT_SLOT(slotClearMidiInLabel()));
+    connect(m_midiInTimer, TQ_SIGNAL(timeout()),
+            TQ_SLOT(slotClearMidiInLabel()));
 
-    connect(m_midiOutTimer, TQT_SIGNAL(timeout()),
-            TQT_SLOT(slotClearMidiOutLabel()));
+    connect(m_midiOutTimer, TQ_SIGNAL(timeout()),
+            TQ_SLOT(slotClearMidiOutLabel()));
 
-    connect(m_clearMetronomeTimer, TQT_SIGNAL(timeout()),
-            TQT_SLOT(slotResetBackground()));
+    connect(m_clearMetronomeTimer, TQ_SIGNAL(timeout()),
+            TQ_SLOT(slotResetBackground()));
 
     m_transport->TimeDisplayLabel->hide();
     m_transport->ToEndLabel->hide();
 
-    connect(m_transport->TimeDisplayButton, TQT_SIGNAL(clicked()),
-            TQT_SLOT(slotChangeTimeDisplay()));
+    connect(m_transport->TimeDisplayButton, TQ_SIGNAL(clicked()),
+            TQ_SLOT(slotChangeTimeDisplay()));
 
-    connect(m_transport->ToEndButton, TQT_SIGNAL(clicked()),
-            TQT_SLOT(slotChangeToEnd()));
+    connect(m_transport->ToEndButton, TQ_SIGNAL(clicked()),
+            TQ_SLOT(slotChangeToEnd()));
 
-    connect(m_transport->LoopButton, TQT_SIGNAL(clicked()),
-            TQT_SLOT(slotLoopButtonClicked()));
+    connect(m_transport->LoopButton, TQ_SIGNAL(clicked()),
+            TQ_SLOT(slotLoopButtonClicked()));
 
-    connect(m_transport->PanelOpenButton, TQT_SIGNAL(clicked()),
-            TQT_SLOT(slotPanelOpenButtonClicked()));
+    connect(m_transport->PanelOpenButton, TQ_SIGNAL(clicked()),
+            TQ_SLOT(slotPanelOpenButtonClicked()));
 
-    connect(m_transport->PanelCloseButton, TQT_SIGNAL(clicked()),
-            TQT_SLOT(slotPanelCloseButtonClicked()));
+    connect(m_transport->PanelCloseButton, TQ_SIGNAL(clicked()),
+            TQ_SLOT(slotPanelCloseButtonClicked()));
 
-    connect(m_transport->PanicButton, TQT_SIGNAL(clicked()), TQT_SIGNAL(panic()));
+    connect(m_transport->PanicButton, TQ_SIGNAL(clicked()), TQ_SIGNAL(panic()));
 
     m_panelOpen = *m_transport->PanelOpenButton->pixmap();
     m_panelClosed = *m_transport->PanelCloseButton->pixmap();
 
 
-    connect(m_transport->SetStartLPButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotSetStartLoopingPointAtMarkerPos()));
-    connect(m_transport->SetStopLPButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotSetStopLoopingPointAtMarkerPos()));
+    connect(m_transport->SetStartLPButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotSetStartLoopingPointAtMarkerPos()));
+    connect(m_transport->SetStopLPButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotSetStopLoopingPointAtMarkerPos()));
 
     // clear labels
     //
@@ -216,46 +216,46 @@ TransportDialog::TransportDialog(TQWidget *parent,
     m_transport->TempoDisplay->setFont( localFont );
     m_transport->TimeSigDisplay->setFont( localFont );
 
-    connect(m_transport->TempoDisplay, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTempo()));
+    connect(m_transport->TempoDisplay, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTempo()));
 
-    connect(m_transport->TempoDisplay, TQT_SIGNAL(scrollWheel(int)),
-            this, TQT_SIGNAL(scrollTempo(int)));
+    connect(m_transport->TempoDisplay, TQ_SIGNAL(scrollWheel(int)),
+            this, TQ_SIGNAL(scrollTempo(int)));
 
-    connect(m_transport->TimeSigDisplay, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTimeSignature()));
+    connect(m_transport->TimeSigDisplay, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTimeSignature()));
 
     // toil through the individual pixmaps
-    connect(m_transport->NegativePixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->TenHoursPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->UnitHoursPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->HourColonPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->TenMinutesPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->UnitMinutesPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->MinuteColonPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->TenSecondsPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->UnitSecondsPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->SecondColonPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->TenthsPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->HundredthsPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->HundredthColonPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->TenThousandthsPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
-    connect(m_transport->ThousandthsPixmap, TQT_SIGNAL(doubleClicked()),
-            this, TQT_SLOT(slotEditTime()));
+    connect(m_transport->NegativePixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->TenHoursPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->UnitHoursPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->HourColonPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->TenMinutesPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->UnitMinutesPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->MinuteColonPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->TenSecondsPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->UnitSecondsPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->SecondColonPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->TenthsPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->HundredthsPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->HundredthColonPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->TenThousandthsPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
+    connect(m_transport->ThousandthsPixmap, TQ_SIGNAL(doubleClicked()),
+            this, TQ_SLOT(slotEditTime()));
 
     // accelerator object
     //
