@@ -124,7 +124,7 @@ EventView::EventView(RosegardenGUIDoc *doc,
     // define some note filtering buttons in a group
     //
     m_filterGroup =
-        new TQButtonGroup(1, Qt::Horizontal, i18n("Event filters"), getCentralWidget());
+        new TQButtonGroup(1, TQt::Horizontal, i18n("Event filters"), getCentralWidget());
 
     m_noteCheckBox = new TQCheckBox(i18n("Note"), m_filterGroup);
     m_programCheckBox = new TQCheckBox(i18n("Program Change"), m_filterGroup);
@@ -141,8 +141,8 @@ EventView::EventView(RosegardenGUIDoc *doc,
 
     // Connect up
     //
-    connect(m_filterGroup, TQT_SIGNAL(released(int)),
-            TQT_SLOT(slotModifyFilter(int)));
+    connect(m_filterGroup, TQ_SIGNAL(released(int)),
+            TQ_SLOT(slotModifyFilter(int)));
 
     m_eventList = new TDEListView(getCentralWidget());
     m_eventList->setItemsRenameable(true);
@@ -156,7 +156,7 @@ EventView::EventView(RosegardenGUIDoc *doc,
             segments[0]->getComposition()->getTriggerSegmentRec(id);
 
         TQGroupBox *groupBox = new TQGroupBox
-                              (1, Qt::Horizontal, i18n("Triggered Segment Properties"), getCentralWidget());
+                              (1, TQt::Horizontal, i18n("Triggered Segment Properties"), getCentralWidget());
 
         TQFrame *frame = new TQFrame(groupBox);
         TQGridLayout *layout = new TQGridLayout(frame, 5, 3, 5, 5);
@@ -169,21 +169,21 @@ EventView::EventView(RosegardenGUIDoc *doc,
         layout->addWidget(m_triggerName, 0, 1);
         TQPushButton *editButton = new TQPushButton(i18n("edit"), frame);
         layout->addWidget(editButton, 0, 2);
-        connect(editButton, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotEditTriggerName()));
+        connect(editButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEditTriggerName()));
 
         layout->addWidget(new TQLabel(i18n("Base pitch:  "), frame), 1, 0);
         m_triggerPitch = new TQLabel(TQString("%1").arg(rec->getBasePitch()), frame);
         layout->addWidget(m_triggerPitch, 1, 1);
         editButton = new TQPushButton(i18n("edit"), frame);
         layout->addWidget(editButton, 1, 2);
-        connect(editButton, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotEditTriggerPitch()));
+        connect(editButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEditTriggerPitch()));
 
         layout->addWidget(new TQLabel(i18n("Base velocity:  "), frame), 2, 0);
         m_triggerVelocity = new TQLabel(TQString("%1").arg(rec->getBaseVelocity()), frame);
         layout->addWidget(m_triggerVelocity, 2, 1);
         editButton = new TQPushButton(i18n("edit"), frame);
         layout->addWidget(editButton, 2, 2);
-        connect(editButton, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotEditTriggerVelocity()));
+        connect(editButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotEditTriggerVelocity()));
 
         /*!!! Comment out these two options, which are not yet used
           anywhere else -- intended for use with library ornaments, not
@@ -209,11 +209,11 @@ EventView::EventView(RosegardenGUIDoc *doc,
             adjust->setCurrentItem(2);
         }
 
-        connect(adjust, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotTriggerTimeAdjustChanged(int)));
+        connect(adjust, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotTriggerTimeAdjustChanged(int)));
             
         TQCheckBox *retune = new TQCheckBox(i18n("Adjust pitch to trigger note by default"), frame);
         retune->setChecked(rec->getDefaultRetune());
-        connect(retune, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotTriggerRetuneChanged()));
+        connect(retune, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotTriggerRetuneChanged()));
         layout->addMultiCellWidget(retune, 4, 4, 1, 2);
 
         */
@@ -230,12 +230,12 @@ EventView::EventView(RosegardenGUIDoc *doc,
 
     // Connect double clicker
     //
-    connect(m_eventList, TQT_SIGNAL(doubleClicked(TQListViewItem*)),
-            TQT_SLOT(slotPopupEventEditor(TQListViewItem*)));
+    connect(m_eventList, TQ_SIGNAL(doubleClicked(TQListViewItem*)),
+            TQ_SLOT(slotPopupEventEditor(TQListViewItem*)));
 
     connect(m_eventList,
-            TQT_SIGNAL(rightButtonPressed(TQListViewItem*, const TQPoint&, int)),
-            TQT_SLOT(slotPopupMenu(TQListViewItem*, const TQPoint&, int)));
+            TQ_SIGNAL(rightButtonPressed(TQListViewItem*, const TQPoint&, int)),
+            TQ_SLOT(slotPopupMenu(TQListViewItem*, const TQPoint&, int)));
 
     m_eventList->setAllColumnsShowFocus(true);
     m_eventList->setSelectionMode(TQListView::Extended);
@@ -1118,42 +1118,42 @@ EventView::setupActions()
     TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQIconSet icon(TQPixmap(pixmapDir + "/toolbar/event-insert.png"));
 
-    new TDEAction(i18n("&Insert Event"), icon, Key_I, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEditInsert()), actionCollection(),
+    new TDEAction(i18n("&Insert Event"), icon, Key_I, this,
+                TQ_SLOT(slotEditInsert()), actionCollection(),
                 "insert");
 
     TQCanvasPixmap pixmap(pixmapDir + "/toolbar/event-delete.png");
     icon = TQIconSet(pixmap);
 
-    new TDEAction(i18n("&Delete Event"), icon, Key_Delete, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEditDelete()), actionCollection(),
+    new TDEAction(i18n("&Delete Event"), icon, Key_Delete, this,
+                TQ_SLOT(slotEditDelete()), actionCollection(),
                 "delete");
 
     pixmap.load(pixmapDir + "/toolbar/event-edit.png");
     icon = TQIconSet(pixmap);
 
-    new TDEAction(i18n("&Edit Event"), icon, Key_E, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEditEvent()), actionCollection(),
+    new TDEAction(i18n("&Edit Event"), icon, Key_E, this,
+                TQ_SLOT(slotEditEvent()), actionCollection(),
                 "edit_simple");
 
     pixmap.load(pixmapDir + "/toolbar/event-edit-advanced.png");
     icon = TQIconSet(pixmap);
 
-    new TDEAction(i18n("&Advanced Event Editor"), icon, Key_A, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEditEventAdvanced()), actionCollection(),
+    new TDEAction(i18n("&Advanced Event Editor"), icon, Key_A, this,
+                TQ_SLOT(slotEditEventAdvanced()), actionCollection(),
                 "edit_advanced");
 
     //    icon = TQIconSet(TQCanvasPixmap(pixmapDir + "/toolbar/eventfilter.xpm"));
-    new TDEAction(i18n("&Filter Selection"), "filter", Key_F, TQT_TQOBJECT(this),
-                TQT_SLOT(slotFilterSelection()), actionCollection(),
+    new TDEAction(i18n("&Filter Selection"), "filter", Key_F, this,
+                TQ_SLOT(slotFilterSelection()), actionCollection(),
                 "filter_selection");
 
-    new TDEAction(i18n("Select &All"), Key_A + CTRL, TQT_TQOBJECT(this),
-                TQT_SLOT(slotSelectAll()), actionCollection(),
+    new TDEAction(i18n("Select &All"), Key_A + CTRL, this,
+                TQ_SLOT(slotSelectAll()), actionCollection(),
                 "select_all");
 
-    new TDEAction(i18n("Clear Selection"), Key_Escape, TQT_TQOBJECT(this),
-                TQT_SLOT(slotClearSelection()), actionCollection(),
+    new TDEAction(i18n("Clear Selection"), Key_Escape, this,
+                TQ_SLOT(slotClearSelection()), actionCollection(),
                 "clear_selection");
 
     m_config->setGroup(EventViewConfigGroup);
@@ -1164,8 +1164,8 @@ EventView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-musical.png");
     icon = TQIconSet(pixmap);
 
-    action = new TDERadioAction(i18n("&Musical Times"), icon, 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotMusicalTime()),
+    action = new TDERadioAction(i18n("&Musical Times"), icon, 0, this,
+                              TQ_SLOT(slotMusicalTime()),
                               actionCollection(), "time_musical");
     action->setExclusiveGroup("timeMode");
     if (timeMode == 0)
@@ -1174,8 +1174,8 @@ EventView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-real.png");
     icon = TQIconSet(pixmap);
 
-    action = new TDERadioAction(i18n("&Real Times"), icon, 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotRealTime()),
+    action = new TDERadioAction(i18n("&Real Times"), icon, 0, this,
+                              TQ_SLOT(slotRealTime()),
                               actionCollection(), "time_real");
     action->setExclusiveGroup("timeMode");
     if (timeMode == 1)
@@ -1184,8 +1184,8 @@ EventView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-raw.png");
     icon = TQIconSet(pixmap);
 
-    action = new TDERadioAction(i18n("Ra&w Times"), icon, 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotRawTime()),
+    action = new TDERadioAction(i18n("Ra&w Times"), icon, 0, this,
+                              TQ_SLOT(slotRawTime()),
                               actionCollection(), "time_raw");
     action->setExclusiveGroup("timeMode");
     if (timeMode == 2)
@@ -1516,8 +1516,8 @@ EventView::createMenu()
     m_menu->insertItem(i18n("Open in Event Editor"), 0);
     m_menu->insertItem(i18n("Open in Expert Event Editor"), 1);
 
-    connect(m_menu, TQT_SIGNAL(activated(int)),
-            TQT_SLOT(slotMenuActivated(int)));
+    connect(m_menu, TQ_SIGNAL(activated(int)),
+            TQ_SLOT(slotMenuActivated(int)));
 }
 
 void
