@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -52,21 +50,21 @@ MatrixEraser::MatrixEraser(MatrixView* parent)
     TQIconSet icon = TQIconSet(pixmap);
 
     new TDEAction(i18n("Switch to Select Tool"), icon, 0, this,
-                TQT_SLOT(slotSelectSelected()), actionCollection(),
+                TQ_SLOT(slotSelectSelected()), actionCollection(),
                 "select");
 
     new TDEAction(i18n("Switch to Draw Tool"), "pencil", 0, this,
-                TQT_SLOT(slotDrawSelected()), actionCollection(),
+                TQ_SLOT(slotDrawSelected()), actionCollection(),
                 "draw");
 
     new TDEAction(i18n("Switch to Move Tool"), "move", 0, this,
-                TQT_SLOT(slotMoveSelected()), actionCollection(),
+                TQ_SLOT(slotMoveSelected()), actionCollection(),
                 "move");
 
     pixmap.load(pixmapDir + "/toolbar/resize.xpm");
     icon = TQIconSet(pixmap);
     new TDEAction(i18n("Switch to Resize Tool"), icon, 0, this,
-                TQT_SLOT(slotResizeSelected()), actionCollection(),
+                TQ_SLOT(slotResizeSelected()), actionCollection(),
                 "resize");
 
     createMenu("matrixeraser.rc");
