@@ -76,10 +76,10 @@ TrackButtons::TrackButtons(RosegardenGUIDoc* doc,
         : TQFrame(parent, name, f),
         m_doc(doc),
         m_layout(new TQVBoxLayout(this)),
-        m_recordSigMapper(new TQSignalMapper(TQT_TQOBJECT(this))),
-        m_muteSigMapper(new TQSignalMapper(TQT_TQOBJECT(this))),
-        m_clickedSigMapper(new TQSignalMapper(TQT_TQOBJECT(this))),
-        m_instListSigMapper(new TQSignalMapper(TQT_TQOBJECT(this))),
+        m_recordSigMapper(new TQSignalMapper(this)),
+        m_muteSigMapper(new TQSignalMapper(this)),
+        m_clickedSigMapper(new TQSignalMapper(this)),
+        m_instListSigMapper(new TQSignalMapper(this)),
         m_tracks(doc->getComposition().getNbTracks()),
         m_offset(4),
         m_cellSize(trackCellHeight),
@@ -106,18 +106,18 @@ TrackButtons::TrackButtons(RosegardenGUIDoc* doc,
 
     m_layout->addStretch(20);
 
-    connect(m_recordSigMapper, TQT_SIGNAL(mapped(int)),
-            this, TQT_SLOT(slotToggleRecordTrack(int)));
+    connect(m_recordSigMapper, TQ_SIGNAL(mapped(int)),
+            this, TQ_SLOT(slotToggleRecordTrack(int)));
 
-    connect(m_muteSigMapper, TQT_SIGNAL(mapped(int)),
-            this, TQT_SLOT(slotToggleMutedTrack(int)));
+    connect(m_muteSigMapper, TQ_SIGNAL(mapped(int)),
+            this, TQ_SLOT(slotToggleMutedTrack(int)));
 
     // connect signal mappers
-    connect(m_instListSigMapper, TQT_SIGNAL(mapped(int)),
-            this, TQT_SLOT(slotInstrumentSelection(int)));
+    connect(m_instListSigMapper, TQ_SIGNAL(mapped(int)),
+            this, TQ_SLOT(slotInstrumentSelection(int)));
 
-    connect(m_clickedSigMapper, TQT_SIGNAL(mapped(int)),
-            this, TQT_SIGNAL(trackSelected(int)));
+    connect(m_clickedSigMapper, TQ_SIGNAL(mapped(int)),
+            this, TQ_SIGNAL(trackSelected(int)));
 
     //     // Populate instrument popup menu just once at start-up
     //     //
@@ -192,7 +192,7 @@ TrackButtons::populateButtons()
 
             // reset track tokens
             m_trackLabels[i]->setId(track->getId());
-            setButtonMapping(TQT_TQOBJECT(m_trackLabels[i]), track->getId());
+            setButtonMapping(m_trackLabels[i], track->getId());
             m_trackLabels[i]->setPosition(i);
         }
 
@@ -357,7 +357,7 @@ TrackButtons::slotUpdateTracks()
 
             //             RG_DEBUG << "TrackButtons::slotUpdateTracks - set button mapping at pos "
             //                      << i << " to track id " << track->getId() << endl;
-            setButtonMapping(TQT_TQOBJECT(m_trackLabels[i]), track->getId());
+            setButtonMapping(m_trackLabels[i], track->getId());
         }
     }
     m_tracks = newNbTracks;
@@ -767,8 +767,8 @@ TrackButtons::populateInstrumentPopup(Instrument *thisTrackInstr, TQPopupMenu* i
 
             // Connect up the submenu
             //
-            connect(subMenu, TQT_SIGNAL(activated(int)),
-                    TQT_SLOT(slotInstrumentPopupActivated(int)));
+            connect(subMenu, TQ_SIGNAL(activated(int)),
+                    TQ_SLOT(slotInstrumentPopupActivated(int)));
 
         } else if (!instrUsedByMe) {
 
@@ -1066,12 +1066,12 @@ TQFrame* TrackButtons::makeButton(Rosegarden::TrackId trackId)
     record->off();
 
     // Connect them to their sigmappers
-    connect(record, TQT_SIGNAL(stateChanged(bool)),
-            m_recordSigMapper, TQT_SLOT(map()));
-    connect(mute, TQT_SIGNAL(stateChanged(bool)),
-            m_muteSigMapper, TQT_SLOT(map()));
-    m_recordSigMapper->setMapping(TQT_TQOBJECT(record), track->getPosition());
-    m_muteSigMapper->setMapping(TQT_TQOBJECT(mute), track->getPosition());
+    connect(record, TQ_SIGNAL(stateChanged(bool)),
+            m_recordSigMapper, TQ_SLOT(map()));
+    connect(mute, TQ_SIGNAL(stateChanged(bool)),
+            m_muteSigMapper, TQ_SLOT(map()));
+    m_recordSigMapper->setMapping(record, track->getPosition());
+    m_muteSigMapper->setMapping(mute, track->getPosition());
 
     // Store the KLedButton
     //
@@ -1101,20 +1101,20 @@ TQFrame* TrackButtons::makeButton(Rosegarden::TrackId trackId)
     trackLabel->setFixedHeight(m_cellSize - buttonGap);
     trackLabel->setIndent(7);
 
-    connect(trackLabel, TQT_SIGNAL(renameTrack(TQString, TrackId)),
-            TQT_SLOT(slotRenameTrack(TQString, TrackId)));
+    connect(trackLabel, TQ_SIGNAL(renameTrack(TQString, TrackId)),
+            TQ_SLOT(slotRenameTrack(TQString, TrackId)));
 
     // Store the TrackLabel pointer
     //
     m_trackLabels.push_back(trackLabel);
 
     // Connect it
-    setButtonMapping(TQT_TQOBJECT(trackLabel), trackId);
+    setButtonMapping(trackLabel, trackId);
 
-    connect(trackLabel, TQT_SIGNAL(changeToInstrumentList()),
-            m_instListSigMapper, TQT_SLOT(map()));
-    connect(trackLabel, TQT_SIGNAL(clicked()),
-            m_clickedSigMapper, TQT_SLOT(map()));
+    connect(trackLabel, TQ_SIGNAL(changeToInstrumentList()),
+            m_instListSigMapper, TQ_SLOT(map()));
+    connect(trackLabel, TQ_SIGNAL(clicked()),
+            m_clickedSigMapper, TQ_SLOT(map()));
 
     //
     // instrument label
