@@ -84,7 +84,7 @@ TempoView::TempoView(RosegardenGUIDoc *doc, TQWidget *parent, timeT openTime):
     // define some note filtering buttons in a group
     //
     m_filterGroup =
-        new TQButtonGroup(1, Qt::Horizontal, i18n("Filter"), getCentralWidget());
+        new TQButtonGroup(1, TQt::Horizontal, i18n("Filter"), getCentralWidget());
 
     m_tempoCheckBox = new TQCheckBox(i18n("Tempo"), m_filterGroup);
     m_timeSigCheckBox = new TQCheckBox(i18n("Time Signature"), m_filterGroup);
@@ -92,8 +92,8 @@ TempoView::TempoView(RosegardenGUIDoc *doc, TQWidget *parent, timeT openTime):
 
     // Connect up
     //
-    connect(m_filterGroup, TQT_SIGNAL(released(int)),
-            TQT_SLOT(slotModifyFilter(int)));
+    connect(m_filterGroup, TQ_SIGNAL(released(int)),
+            TQ_SLOT(slotModifyFilter(int)));
 
     m_list = new TDEListView(getCentralWidget());
     m_list->setItemsRenameable(true);
@@ -106,8 +106,8 @@ TempoView::TempoView(RosegardenGUIDoc *doc, TQWidget *parent, timeT openTime):
 
     // Connect double clicker
     //
-    connect(m_list, TQT_SIGNAL(doubleClicked(TQListViewItem*)),
-            TQT_SLOT(slotPopupEditor(TQListViewItem*)));
+    connect(m_list, TQ_SIGNAL(doubleClicked(TQListViewItem*)),
+            TQ_SLOT(slotPopupEditor(TQListViewItem*)));
 
     m_list->setAllColumnsShowFocus(true);
     m_list->setSelectionMode(TQListView::Extended);
@@ -487,12 +487,12 @@ TempoView::slotEditInsertTempo()
     dialog.setTempoPosition(insertTime);
 
     connect(&dialog,
-            TQT_SIGNAL(changeTempo(timeT,
+            TQ_SIGNAL(changeTempo(timeT,
                                tempoT,
                                tempoT,
                                TempoDialog::TempoDialogAction)),
             this,
-            TQT_SIGNAL(changeTempo(timeT,
+            TQ_SIGNAL(changeTempo(timeT,
                                tempoT,
                                tempoT,
                                TempoDialog::TempoDialogAction)));
@@ -576,37 +576,37 @@ TempoView::setupActions()
     TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQIconSet icon(TQPixmap(pixmapDir + "/toolbar/event-insert-tempo.png"));
 
-    new TDEAction(AddTempoChangeCommand::getGlobalName(), icon, Key_I, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEditInsertTempo()), actionCollection(),
+    new TDEAction(AddTempoChangeCommand::getGlobalName(), icon, Key_I, this,
+                TQ_SLOT(slotEditInsertTempo()), actionCollection(),
                 "insert_tempo");
 
     TQCanvasPixmap pixmap(pixmapDir + "/toolbar/event-insert-timesig.png");
     icon = TQIconSet(pixmap);
 
-    new TDEAction(AddTimeSignatureCommand::getGlobalName(), icon, Key_G, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEditInsertTimeSignature()), actionCollection(),
+    new TDEAction(AddTimeSignatureCommand::getGlobalName(), icon, Key_G, this,
+                TQ_SLOT(slotEditInsertTimeSignature()), actionCollection(),
                 "insert_timesig");
 
     pixmap.load(pixmapDir + "/toolbar/event-delete.png");
     icon = TQIconSet(pixmap);
 
-    new TDEAction(i18n("&Delete"), icon, Key_Delete, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEditDelete()), actionCollection(),
+    new TDEAction(i18n("&Delete"), icon, Key_Delete, this,
+                TQ_SLOT(slotEditDelete()), actionCollection(),
                 "delete");
 
     pixmap.load(pixmapDir + "/toolbar/event-edit.png");
     icon = TQIconSet(pixmap);
 
-    new TDEAction(i18n("&Edit Item"), icon, Key_E, TQT_TQOBJECT(this),
-                TQT_SLOT(slotEdit()), actionCollection(),
+    new TDEAction(i18n("&Edit Item"), icon, Key_E, this,
+                TQ_SLOT(slotEdit()), actionCollection(),
                 "edit");
 
-    new TDEAction(i18n("Select &All"), 0, TQT_TQOBJECT(this),
-                TQT_SLOT(slotSelectAll()), actionCollection(),
+    new TDEAction(i18n("Select &All"), 0, this,
+                TQ_SLOT(slotSelectAll()), actionCollection(),
                 "select_all");
 
-    new TDEAction(i18n("Clear Selection"), Key_Escape, TQT_TQOBJECT(this),
-                TQT_SLOT(slotClearSelection()), actionCollection(),
+    new TDEAction(i18n("Clear Selection"), Key_Escape, this,
+                TQ_SLOT(slotClearSelection()), actionCollection(),
                 "clear_selection");
 
     m_config->setGroup(TempoViewConfigGroup);
@@ -617,8 +617,8 @@ TempoView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-musical.png");
     icon = TQIconSet(pixmap);
 
-    action = new TDERadioAction(i18n("&Musical Times"), icon, 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotMusicalTime()),
+    action = new TDERadioAction(i18n("&Musical Times"), icon, 0, this,
+                              TQ_SLOT(slotMusicalTime()),
                               actionCollection(), "time_musical");
     action->setExclusiveGroup("timeMode");
     if (timeMode == 0)
@@ -627,8 +627,8 @@ TempoView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-real.png");
     icon = TQIconSet(pixmap);
 
-    action = new TDERadioAction(i18n("&Real Times"), icon, 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotRealTime()),
+    action = new TDERadioAction(i18n("&Real Times"), icon, 0, this,
+                              TQ_SLOT(slotRealTime()),
                               actionCollection(), "time_real");
     action->setExclusiveGroup("timeMode");
     if (timeMode == 1)
@@ -637,8 +637,8 @@ TempoView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-raw.png");
     icon = TQIconSet(pixmap);
 
-    action = new TDERadioAction(i18n("Ra&w Times"), icon, 0, TQT_TQOBJECT(this),
-                              TQT_SLOT(slotRawTime()),
+    action = new TDERadioAction(i18n("Ra&w Times"), icon, 0, this,
+                              TQ_SLOT(slotRawTime()),
                               actionCollection(), "time_raw");
     action->setExclusiveGroup("timeMode");
     if (timeMode == 2)
@@ -784,12 +784,12 @@ TempoView::slotPopupEditor(TQListViewItem *qitem)
         dialog.setTempoPosition(time);
         
         connect(&dialog,
-                TQT_SIGNAL(changeTempo(timeT,
+                TQ_SIGNAL(changeTempo(timeT,
                                    tempoT,
                                    tempoT,
                                    TempoDialog::TempoDialogAction)),
                 this,
-                TQT_SIGNAL(changeTempo(timeT,
+                TQ_SIGNAL(changeTempo(timeT,
                                    tempoT,
                                    tempoT,
                                    TempoDialog::TempoDialogAction)));
