@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -80,7 +78,7 @@ MarkerRuler::MarkerRuler(RosegardenGUIDoc *doc,
     // Otherwise we'll end up adding all actions to the same
     // (document-level) action collection regardless of which window
     // we're in.
-    TQObject *probe = TQT_TQOBJECT(parent);
+    TQObject *probe = parent;
     while (probe && !dynamic_cast<TDEMainWindow *>(probe)) probe = probe->parent();
     if (probe) m_parentMainWindow = dynamic_cast<TDEMainWindow *>(probe);
 
@@ -97,22 +95,22 @@ MarkerRuler::MarkerRuler(RosegardenGUIDoc *doc,
     // don't become more event-specific in future...
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/event-insert.png"));
-    new TDEAction(i18n("Insert Marker"), icon, 0, TQT_TQOBJECT(this),
-             TQT_SLOT(slotInsertMarkerHere()), actionCollection(),
+    new TDEAction(i18n("Insert Marker"), icon, 0, this,
+             TQ_SLOT(slotInsertMarkerHere()), actionCollection(),
              "insert_marker_here");
     
-    new TDEAction(i18n("Insert Marker at Playback Position"), 0, TQT_TQOBJECT(this),
-             TQT_SLOT(slotInsertMarkerAtPointer()), actionCollection(),
+    new TDEAction(i18n("Insert Marker at Playback Position"), 0, this,
+             TQ_SLOT(slotInsertMarkerAtPointer()), actionCollection(),
              "insert_marker_at_pointer");
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/event-delete.png"));
-    new TDEAction(i18n("Delete Marker"), icon, 0, TQT_TQOBJECT(this),
-             TQT_SLOT(slotDeleteMarker()), actionCollection(),
+    new TDEAction(i18n("Delete Marker"), icon, 0, this,
+             TQ_SLOT(slotDeleteMarker()), actionCollection(),
              "delete_marker");
     
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/event-edit.png"));
-    new TDEAction(i18n("Edit Marker..."), icon, 0, TQT_TQOBJECT(this),
-                 TQT_SLOT(slotEditMarker()), actionCollection(),
+    new TDEAction(i18n("Edit Marker..."), icon, 0, this,
+                 TQ_SLOT(slotEditMarker()), actionCollection(),
                  "edit_marker");
 
     TQToolTip::add
@@ -432,7 +430,7 @@ MarkerRuler::mousePressEvent(TQMouseEvent *e)
     
     // if right-click, show popup menu
     //
-    if (e->button() == Qt::RightButton) {
+    if (e->button() == TQt::RightButton) {
         if (!m_menu)
             createMenu();
         if (m_menu) {
