@@ -115,45 +115,45 @@ TempoRuler::TempoRuler(RulerScale *rulerScale,
     setBackgroundMode(TQt::NoBackground);
 
     TQObject::connect
-    (doc->getCommandHistory(), TQT_SIGNAL(commandExecuted()),
-     this, TQT_SLOT(update()));
+    (doc->getCommandHistory(), TQ_SIGNAL(commandExecuted()),
+     this, TQ_SLOT(update()));
 
     TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQIconSet icon;
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/event-insert-tempo.png"));
-    new TDEAction(i18n("Insert Tempo Change"), icon, 0, TQT_TQOBJECT(this),
-                 TQT_SLOT(slotInsertTempoHere()), actionCollection(),
+    new TDEAction(i18n("Insert Tempo Change"), icon, 0, this,
+                 TQ_SLOT(slotInsertTempoHere()), actionCollection(),
                  "insert_tempo_here");
 
-    new TDEAction(i18n("Insert Tempo Change at Playback Position"), 0, 0, TQT_TQOBJECT(this),
-                 TQT_SLOT(slotInsertTempoAtPointer()), actionCollection(),
+    new TDEAction(i18n("Insert Tempo Change at Playback Position"), 0, 0, this,
+                 TQ_SLOT(slotInsertTempoAtPointer()), actionCollection(),
                  "insert_tempo_at_pointer");
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/event-delete.png"));
-    new TDEAction(i18n("Delete Tempo Change"), icon, 0, TQT_TQOBJECT(this),
-                 TQT_SLOT(slotDeleteTempoChange()), actionCollection(),
+    new TDEAction(i18n("Delete Tempo Change"), icon, 0, this,
+                 TQ_SLOT(slotDeleteTempoChange()), actionCollection(),
                  "delete_tempo");
 
-    new TDEAction(i18n("Ramp Tempo to Next Tempo"), 0, 0, TQT_TQOBJECT(this),
-                 TQT_SLOT(slotRampToNext()), actionCollection(),
+    new TDEAction(i18n("Ramp Tempo to Next Tempo"), 0, 0, this,
+                 TQ_SLOT(slotRampToNext()), actionCollection(),
                  "ramp_to_next");
 
-    new TDEAction(i18n("Un-Ramp Tempo"), 0, 0, TQT_TQOBJECT(this),
-                 TQT_SLOT(slotUnramp()), actionCollection(),
+    new TDEAction(i18n("Un-Ramp Tempo"), 0, 0, this,
+                 TQ_SLOT(slotUnramp()), actionCollection(),
                  "unramp");
 
     icon = TQIconSet(TQPixmap(pixmapDir + "/toolbar/event-edit.png"));
-    new TDEAction(i18n("Edit Tempo..."), icon, 0, TQT_TQOBJECT(this),
-                 TQT_SLOT(slotEditTempo()), actionCollection(),
+    new TDEAction(i18n("Edit Tempo..."), icon, 0, this,
+                 TQ_SLOT(slotEditTempo()), actionCollection(),
                  "edit_tempo");
 
-    new TDEAction(i18n("Edit Time Signature..."), 0, 0, TQT_TQOBJECT(this),
-                 TQT_SLOT(slotEditTimeSignature()), actionCollection(),
+    new TDEAction(i18n("Edit Time Signature..."), 0, 0, this,
+                 TQ_SLOT(slotEditTimeSignature()), actionCollection(),
                  "edit_time_signature");
 
-    new TDEAction(i18n("Open Tempo and Time Signature Editor"), 0, 0, TQT_TQOBJECT(this),
-                 TQT_SLOT(slotEditTempos()), actionCollection(),
+    new TDEAction(i18n("Open Tempo and Time Signature Editor"), 0, 0, this,
+                 TQ_SLOT(slotEditTempos()), actionCollection(),
                  "edit_tempos");
 
     setMouseTracking(false);
@@ -172,47 +172,47 @@ void
 TempoRuler::connectSignals()
 {
     connect(this,
-            TQT_SIGNAL(doubleClicked(timeT)),
+            TQ_SIGNAL(doubleClicked(timeT)),
             RosegardenGUIApp::self(),
-            TQT_SLOT(slotEditTempos(timeT)));
+            TQ_SLOT(slotEditTempos(timeT)));
 
     connect(this,
-            TQT_SIGNAL(changeTempo(timeT,
+            TQ_SIGNAL(changeTempo(timeT,
                                tempoT,
                                tempoT,
                                TempoDialog::TempoDialogAction)),
             RosegardenGUIApp::self(),
-            TQT_SLOT(slotChangeTempo(timeT,
+            TQ_SLOT(slotChangeTempo(timeT,
                                  tempoT,
                                  tempoT,
                                  TempoDialog::TempoDialogAction)));
 
     connect(this,
-            TQT_SIGNAL(moveTempo(timeT,
+            TQ_SIGNAL(moveTempo(timeT,
                              timeT)),
             RosegardenGUIApp::self(),
-            TQT_SLOT(slotMoveTempo(timeT,
+            TQ_SLOT(slotMoveTempo(timeT,
                                timeT)));
 
     connect(this,
-            TQT_SIGNAL(deleteTempo(timeT)),
+            TQ_SIGNAL(deleteTempo(timeT)),
             RosegardenGUIApp::self(),
-            TQT_SLOT(slotDeleteTempo(timeT)));
+            TQ_SLOT(slotDeleteTempo(timeT)));
 
     connect(this,
-            TQT_SIGNAL(editTempo(timeT)),
+            TQ_SIGNAL(editTempo(timeT)),
             RosegardenGUIApp::self(),
-            TQT_SLOT(slotEditTempo(timeT)));
+            TQ_SLOT(slotEditTempo(timeT)));
 
     connect(this,
-            TQT_SIGNAL(editTimeSignature(timeT)),
+            TQ_SIGNAL(editTimeSignature(timeT)),
             RosegardenGUIApp::self(),
-            TQT_SLOT(slotEditTimeSignature(timeT)));
+            TQ_SLOT(slotEditTimeSignature(timeT)));
 
     connect(this,
-            TQT_SIGNAL(editTempos(timeT)),
+            TQ_SIGNAL(editTempos(timeT)),
             RosegardenGUIApp::self(),
-            TQT_SLOT(slotEditTempos(timeT)));
+            TQ_SLOT(slotEditTempos(timeT)));
 }
 
 void
@@ -239,7 +239,7 @@ TempoRuler::slotScrollHoriz(int x)
 void
 TempoRuler::mousePressEvent(TQMouseEvent *e)
 {
-    if (e->button() == Qt::LeftButton) {
+    if (e->button() == TQt::LeftButton) {
 
         if (e->type() == TQEvent::MouseButtonDblClick) {
             timeT t = m_rulerScale->getTimeForX
@@ -291,7 +291,7 @@ TempoRuler::mousePressEvent(TQMouseEvent *e)
             m_dragHoriz = false;
         }
 
-    } else if (e->button() == Qt::RightButton) {
+    } else if (e->button() == TQt::RightButton) {
 
         m_clickX = e->x();
         if (!m_menu)
