@@ -115,18 +115,18 @@ SequenceManager::SequenceManager(RosegardenGUIDoc *doc,
                                             (m_doc->parent())->parentWidget());
     // Connect these for use later
     //
-    connect(m_countdownTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(slotCountdownTimerTimeout()));
+    connect(m_countdownTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(slotCountdownTimerTimeout()));
 
-    connect(m_reportTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(slotAllowReport()));
+    connect(m_reportTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(slotAllowReport()));
 
-    connect(m_compositionMmapperResetTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(slotScheduledCompositionMmapperReset()));
+    connect(m_compositionMmapperResetTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(slotScheduledCompositionMmapperReset()));
 
 
-    connect(doc->getCommandHistory(), TQT_SIGNAL(commandExecuted()),
-            this, TQT_SLOT(update()));
+    connect(doc->getCommandHistory(), TQ_SIGNAL(commandExecuted()),
+            this, TQ_SLOT(update()));
 
     m_doc->getComposition().addObserver(this);
 
@@ -162,7 +162,7 @@ void SequenceManager::setDocument(RosegardenGUIDoc* doc)
     DataBlockRepository::clear();
 
     m_doc->getComposition().removeObserver(this);
-    disconnect(m_doc->getCommandHistory(), TQT_SIGNAL(commandExecuted()));
+    disconnect(m_doc->getCommandHistory(), TQ_SIGNAL(commandExecuted()));
 
     m_segments.clear();
     m_triggerSegments.clear();
@@ -188,14 +188,14 @@ void SequenceManager::setDocument(RosegardenGUIDoc* doc)
 
     // Connect this for use later
     //
-    connect(m_countdownTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(slotCountdownTimerTimeout()));
+    connect(m_countdownTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(slotCountdownTimerTimeout()));
 
     m_compositionRefreshStatusId = comp.getNewRefreshStatusId();
     comp.addObserver(this);
 
-    connect(m_doc->getCommandHistory(), TQT_SIGNAL(commandExecuted()),
-            this, TQT_SLOT(update()));
+    connect(m_doc->getCommandHistory(), TQ_SIGNAL(commandExecuted()),
+            this, TQ_SLOT(update()));
 
     for (Composition::iterator i = comp.begin(); i != comp.end(); ++i) {
 
@@ -215,8 +215,8 @@ void SequenceManager::setDocument(RosegardenGUIDoc* doc)
 
 
     m_compositionMmapperResetTimer = new TQTimer(m_doc);
-    connect(m_compositionMmapperResetTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(slotScheduledCompositionMmapperReset()));
+    connect(m_compositionMmapperResetTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(slotScheduledCompositionMmapperReset()));
 
     resetCompositionMmapper();
 
