@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -96,14 +94,14 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
 {
     populate();
 
-    KStdAction::close(TQT_TQOBJECT(this),
-                      TQT_SLOT(slotClose()),
+    KStdAction::close(this,
+                      TQ_SLOT(slotClose()),
                       actionCollection());
 
     TQIconSet icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                              ("transport-play")));
-    TDEAction *play = new TDEAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
-                TQT_SIGNAL(play()), actionCollection(), "play");
+    TDEAction *play = new TDEAction(i18n("&Play"), icon, Key_Enter, this,
+                TQ_SIGNAL(play()), actionCollection(), "play");
     // Alternative shortcut for Play
     TDEShortcut playShortcut = play->shortcut();
     playShortcut.append( KKey(Key_Return + CTRL) );
@@ -111,69 +109,69 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-stop")));
-    new TDEAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
-                TQT_SIGNAL(stop()), actionCollection(), "stop");
+    new TDEAction(i18n("&Stop"), icon, Key_Insert, this,
+                TQ_SIGNAL(stop()), actionCollection(), "stop");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind")));
-    new TDEAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
-                TQT_SIGNAL(rewindPlayback()), actionCollection(),
+    new TDEAction(i18n("Re&wind"), icon, Key_End, this,
+                TQ_SIGNAL(rewindPlayback()), actionCollection(),
                 "playback_pointer_back_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd")));
-    new TDEAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
-                TQT_SIGNAL(fastForwardPlayback()), actionCollection(),
+    new TDEAction(i18n("&Fast Forward"), icon, Key_PageDown, this,
+                TQ_SIGNAL(fastForwardPlayback()), actionCollection(),
                 "playback_pointer_forward_bar");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-rewind-end")));
-    new TDEAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
+    new TDEAction(i18n("Rewind to &Beginning"), icon, 0, this,
+                TQ_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
                 "playback_pointer_start");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-ffwd-end")));
-    new TDEAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
+    new TDEAction(i18n("Fast Forward to &End"), icon, 0, this,
+                TQ_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
                 "playback_pointer_end");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-record")));
-    new TDEAction(i18n("&Record"), icon, 0, TQT_TQOBJECT(this),
-                TQT_SIGNAL(record()), actionCollection(),
+    new TDEAction(i18n("&Record"), icon, 0, this,
+                TQ_SIGNAL(record()), actionCollection(),
                 "record");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
                     ("transport-panic")));
-    new TDEAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
-                TQT_SIGNAL(panic()), actionCollection(),
+    new TDEAction(i18n("Panic"), icon, Key_P + CTRL + ALT, this,
+                TQ_SIGNAL(panic()), actionCollection(),
                 "panic");
 
     unsigned int mixerOptions = m_studio->getMixerDisplayOptions();
 
-    (new TDEToggleAction(i18n("Show Audio &Faders"), 0, TQT_TQOBJECT(this),
-                       TQT_SLOT(slotToggleFaders()), actionCollection(),
+    (new TDEToggleAction(i18n("Show Audio &Faders"), 0, this,
+                       TQ_SLOT(slotToggleFaders()), actionCollection(),
                        "show_audio_faders"))->setChecked
     (!(mixerOptions & MIXER_OMIT_FADERS));
 
-    (new TDEToggleAction(i18n("Show Synth &Faders"), 0, TQT_TQOBJECT(this),
-                       TQT_SLOT(slotToggleSynthFaders()), actionCollection(),
+    (new TDEToggleAction(i18n("Show Synth &Faders"), 0, this,
+                       TQ_SLOT(slotToggleSynthFaders()), actionCollection(),
                        "show_synth_faders"))->setChecked
     (!(mixerOptions & MIXER_OMIT_SYNTH_FADERS));
 
-    (new TDEToggleAction(i18n("Show &Submasters"), 0, TQT_TQOBJECT(this),
-                       TQT_SLOT(slotToggleSubmasters()), actionCollection(),
+    (new TDEToggleAction(i18n("Show &Submasters"), 0, this,
+                       TQ_SLOT(slotToggleSubmasters()), actionCollection(),
                        "show_audio_submasters"))->setChecked
     (!(mixerOptions & MIXER_OMIT_SUBMASTERS));
 
-    (new TDEToggleAction(i18n("Show &Plugin Buttons"), 0, TQT_TQOBJECT(this),
-                       TQT_SLOT(slotTogglePluginButtons()), actionCollection(),
+    (new TDEToggleAction(i18n("Show &Plugin Buttons"), 0, this,
+                       TQ_SLOT(slotTogglePluginButtons()), actionCollection(),
                        "show_plugin_buttons"))->setChecked
     (!(mixerOptions & MIXER_OMIT_PLUGINS));
 
-    (new TDEToggleAction(i18n("Show &Unassigned Faders"), 0, TQT_TQOBJECT(this),
-                       TQT_SLOT(slotToggleUnassignedFaders()), actionCollection(),
+    (new TDEToggleAction(i18n("Show &Unassigned Faders"), 0, this,
+                       TQ_SLOT(slotToggleUnassignedFaders()), actionCollection(),
                        "show_unassigned_faders"))->setChecked
     (mixerOptions & MIXER_SHOW_UNASSIGNED_FADERS);
 
@@ -182,8 +180,8 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
     for (int i = 1; i <= 16; i *= 2) {
         action =
             new TDERadioAction(i18n("1 Input", "%n Inputs", i),
-                             0, TQT_TQOBJECT(this),
-                             TQT_SLOT(slotSetInputCountFromAction()), actionCollection(),
+                             0, this,
+                             TQ_SLOT(slotSetInputCountFromAction()), actionCollection(),
                              TQString("inputs_%1").arg(i).ascii());
         action->setExclusiveGroup("inputs");
         if (i == int(m_studio->getRecordIns().size()))
@@ -192,8 +190,8 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
 
     action = new TDERadioAction
              (i18n("No Submasters"),
-              0, TQT_TQOBJECT(this),
-              TQT_SLOT(slotSetSubmasterCountFromAction()), actionCollection(),
+              0, this,
+              TQ_SLOT(slotSetSubmasterCountFromAction()), actionCollection(),
               TQString("submasters_0").ascii());
     action->setExclusiveGroup("submasters");
     action->setChecked(true);
@@ -201,8 +199,8 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
     for (int i = 2; i <= 8; i *= 2) {
         action = new TDERadioAction
                  (i18n("1 Submaster", "%n Submasters", i),
-                  0, TQT_TQOBJECT(this),
-                  TQT_SLOT(slotSetSubmasterCountFromAction()), actionCollection(),
+                  0, this,
+                  TQ_SLOT(slotSetSubmasterCountFromAction()), actionCollection(),
                   TQString("submasters_%1").arg(i).ascii());
         action->setExclusiveGroup("submasters");
         if (i == int(m_studio->getBusses().size()) - 1)
@@ -390,8 +388,8 @@ AudioMixerWindow::populate()
             TQToolTip::add
                 (plugin, i18n("Audio plugin button"));
             rec.m_plugins.push_back(plugin);
-            connect(plugin, TQT_SIGNAL(clicked()),
-                    this, TQT_SLOT(slotSelectPlugin()));
+            connect(plugin, TQ_SIGNAL(clicked()),
+                    this, TQ_SLOT(slotSelectPlugin()));
         }
 
         TQLabel *idLabel;
@@ -443,30 +441,30 @@ AudioMixerWindow::populate()
         updatePluginButtons((*i)->getId());
 
         if (rec.m_input) {
-            connect(rec.m_input, TQT_SIGNAL(changed()),
-                    this, TQT_SLOT(slotInputChanged()));
+            connect(rec.m_input, TQ_SIGNAL(changed()),
+                    this, TQ_SLOT(slotInputChanged()));
         }
 
-        connect(rec.m_output, TQT_SIGNAL(changed()),
-                this, TQT_SLOT(slotOutputChanged()));
+        connect(rec.m_output, TQ_SIGNAL(changed()),
+                this, TQ_SLOT(slotOutputChanged()));
 
-        connect(rec.m_fader, TQT_SIGNAL(faderChanged(float)),
-                this, TQT_SLOT(slotFaderLevelChanged(float)));
+        connect(rec.m_fader, TQ_SIGNAL(faderChanged(float)),
+                this, TQ_SLOT(slotFaderLevelChanged(float)));
 
-        connect(rec.m_pan, TQT_SIGNAL(valueChanged(float)),
-                this, TQT_SLOT(slotPanChanged(float)));
+        connect(rec.m_pan, TQ_SIGNAL(valueChanged(float)),
+                this, TQ_SLOT(slotPanChanged(float)));
 
-        connect(rec.m_soloButton, TQT_SIGNAL(clicked()),
-                this, TQT_SLOT(slotSoloChanged()));
+        connect(rec.m_soloButton, TQ_SIGNAL(clicked()),
+                this, TQ_SLOT(slotSoloChanged()));
 
-        connect(rec.m_muteButton, TQT_SIGNAL(clicked()),
-                this, TQT_SLOT(slotMuteChanged()));
+        connect(rec.m_muteButton, TQ_SIGNAL(clicked()),
+                this, TQ_SLOT(slotMuteChanged()));
 
-        connect(rec.m_stereoButton, TQT_SIGNAL(clicked()),
-                this, TQT_SLOT(slotChannelsChanged()));
+        connect(rec.m_stereoButton, TQ_SIGNAL(clicked()),
+                this, TQ_SLOT(slotChannelsChanged()));
 
-        connect(rec.m_recordButton, TQT_SIGNAL(clicked()),
-                this, TQT_SLOT(slotRecordChanged()));
+        connect(rec.m_recordButton, TQ_SIGNAL(clicked()),
+                this, TQ_SLOT(slotRecordChanged()));
 
         ++count;
 
@@ -521,8 +519,8 @@ AudioMixerWindow::populate()
             TQToolTip::add
                 (plugin, i18n("Audio plugin button"));
             rec.m_plugins.push_back(plugin);
-            connect(plugin, TQT_SIGNAL(clicked()),
-                    this, TQT_SLOT(slotSelectPlugin()));
+            connect(plugin, TQ_SIGNAL(clicked()),
+                    this, TQ_SLOT(slotSelectPlugin()));
         }
 
         TQLabel *idLabel = new TQLabel(i18n("Sub %1").arg(count), m_mainBox, "subMaster");
@@ -548,14 +546,14 @@ AudioMixerWindow::populate()
         updateFader(count);
         updatePluginButtons(count);
 
-        connect(rec.m_fader, TQT_SIGNAL(faderChanged(float)),
-                this, TQT_SLOT(slotFaderLevelChanged(float)));
+        connect(rec.m_fader, TQ_SIGNAL(faderChanged(float)),
+                this, TQ_SLOT(slotFaderLevelChanged(float)));
 
-        connect(rec.m_pan, TQT_SIGNAL(valueChanged(float)),
-                this, TQT_SLOT(slotPanChanged(float)));
+        connect(rec.m_pan, TQ_SIGNAL(valueChanged(float)),
+                this, TQ_SLOT(slotPanChanged(float)));
 
-        connect(rec.m_muteButton, TQT_SIGNAL(clicked()),
-                this, TQT_SLOT(slotMuteChanged()));
+        connect(rec.m_muteButton, TQ_SIGNAL(clicked()),
+                this, TQ_SLOT(slotMuteChanged()));
 
         ++count;
 
@@ -599,11 +597,11 @@ AudioMixerWindow::populate()
         m_master = rec;
         updateFader(0);
 
-        connect(rec.m_fader, TQT_SIGNAL(faderChanged(float)),
-                this, TQT_SLOT(slotFaderLevelChanged(float)));
+        connect(rec.m_fader, TQ_SIGNAL(faderChanged(float)),
+                this, TQ_SLOT(slotFaderLevelChanged(float)));
 
-        connect(rec.m_muteButton, TQT_SIGNAL(clicked()),
-                this, TQT_SLOT(slotMuteChanged()));
+        connect(rec.m_muteButton, TQ_SIGNAL(clicked()),
+                this, TQ_SLOT(slotMuteChanged()));
     }
 
     m_mainBox->show();
@@ -942,7 +940,7 @@ AudioMixerWindow::updatePluginButtons(int id)
 void
 AudioMixerWindow::slotSelectPlugin()
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
 
     for (FaderMap::iterator i = m_faders.begin();
             i != m_faders.end(); ++i) {
@@ -954,7 +952,7 @@ AudioMixerWindow::slotSelectPlugin()
         for (std::vector<TQPushButton *>::iterator pli = i->second.m_plugins.begin();
                 pli != i->second.m_plugins.end(); ++pli) {
 
-            if (TQT_BASE_OBJECT(*pli) == TQT_BASE_OBJECT_CONST(s)) {
+            if (*pli == s) {
 
                 emit selectPlugin(this, i->first, index);
                 return ;
@@ -977,7 +975,7 @@ AudioMixerWindow::slotSelectPlugin()
         for (std::vector<TQPushButton *>::iterator pli = i->m_plugins.begin();
                 pli != i->m_plugins.end(); ++pli) {
 
-            if (TQT_BASE_OBJECT(*pli) == TQT_BASE_OBJECT_CONST(s)) {
+            if (*pli == s) {
 
                 emit selectPlugin(this, b, index);
                 return ;
@@ -993,7 +991,7 @@ AudioMixerWindow::slotSelectPlugin()
 void
 AudioMixerWindow::slotInputChanged()
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
 
     for (FaderMap::iterator i = m_faders.begin();
             i != m_faders.end(); ++i) {
@@ -1006,7 +1004,7 @@ AudioMixerWindow::slotInputChanged()
 void
 AudioMixerWindow::slotOutputChanged()
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
 
     for (FaderMap::iterator i = m_faders.begin();
             i != m_faders.end(); ++i) {
@@ -1060,11 +1058,11 @@ AudioMixerWindow::sendControllerRefresh()
 void
 AudioMixerWindow::slotFaderLevelChanged(float dB)
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
 
     BussList busses = m_studio->getBusses();
 
-    if (TQT_BASE_OBJECT(m_master.m_fader) == TQT_BASE_OBJECT_CONST(s)) {
+    if (m_master.m_fader == s) {
 
         if (busses.size() > 0) {
             StudioControl::setStudioObjectProperty
@@ -1082,7 +1080,7 @@ AudioMixerWindow::slotFaderLevelChanged(float dB)
     for (FaderVector::iterator i = m_submasters.begin();
             i != m_submasters.end(); ++i) {
 
-        if (TQT_BASE_OBJECT(i->m_fader) == TQT_BASE_OBJECT_CONST(s)) {
+        if (i->m_fader == s) {
             if ((int)busses.size() > index) {
                 StudioControl::setStudioObjectProperty
                 (MappedObjectId(busses[index]->getMappedId()),
@@ -1102,7 +1100,7 @@ AudioMixerWindow::slotFaderLevelChanged(float dB)
     for (FaderMap::iterator i = m_faders.begin();
             i != m_faders.end(); ++i) {
 
-        if (TQT_BASE_OBJECT(i->second.m_fader) == TQT_BASE_OBJECT_CONST(s)) {
+        if (i->second.m_fader == s) {
 
             Instrument *instrument =
                 m_studio->getInstrumentById(i->first);
@@ -1140,7 +1138,7 @@ AudioMixerWindow::slotFaderLevelChanged(float dB)
 void
 AudioMixerWindow::slotPanChanged(float pan)
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
 
     BussList busses = m_studio->getBusses();
 
@@ -1149,7 +1147,7 @@ AudioMixerWindow::slotPanChanged(float pan)
     for (FaderVector::iterator i = m_submasters.begin();
             i != m_submasters.end(); ++i) {
 
-        if (TQT_BASE_OBJECT(i->m_pan) == TQT_BASE_OBJECT_CONST(s)) {
+        if (i->m_pan == s) {
             if ((int)busses.size() > index) {
                 StudioControl::setStudioObjectProperty
                 (MappedObjectId(busses[index]->getMappedId()),
@@ -1168,7 +1166,7 @@ AudioMixerWindow::slotPanChanged(float pan)
     for (FaderMap::iterator i = m_faders.begin();
             i != m_faders.end(); ++i) {
 
-        if (TQT_BASE_OBJECT(i->second.m_pan) == TQT_BASE_OBJECT_CONST(s)) {
+        if (i->second.m_pan == s) {
 
             Instrument *instrument =
                 m_studio->getInstrumentById(i->first);
@@ -1208,7 +1206,7 @@ AudioMixerWindow::slotPanChanged(float pan)
 void
 AudioMixerWindow::slotChannelsChanged()
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
 
     // channels are only switchable on instruments
 
@@ -1218,7 +1216,7 @@ AudioMixerWindow::slotChannelsChanged()
     for (FaderMap::iterator i = m_faders.begin();
             i != m_faders.end(); ++i) {
 
-        if (TQT_BASE_OBJECT_CONST(s) == TQT_BASE_OBJECT(i->second.m_stereoButton)) {
+        if (s == i->second.m_stereoButton) {
 
             Instrument *instrument =
                 m_studio->getInstrumentById(i->first);
@@ -1444,7 +1442,7 @@ AudioMixerWindow::slotControllerDeviceEventReceived(MappedEvent *e,
 void
 AudioMixerWindow::slotSetInputCountFromAction()
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
     TQString name = s->name();
 
     if (name.left(7) == "inputs_") {
@@ -1475,7 +1473,7 @@ AudioMixerWindow::slotSetInputCountFromAction()
 void
 AudioMixerWindow::slotSetSubmasterCountFromAction()
 {
-    const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
+    const TQObject *s = sender();
     TQString name = s->name();
 
     if (name.left(11) == "submasters_") {
