@@ -1,5 +1,3 @@
-/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */
-
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
@@ -51,8 +49,8 @@ ColourTable::ColourTable
     horizontalHeader()->setLabel(0, i18n("Name"));
     horizontalHeader()->setLabel(1, i18n("Color"));
     populate_table(input, list);
-    connect(this, TQT_SIGNAL(doubleClicked(int, int, int, const TQPoint&)),
-            TQT_SLOT(slotEditEntry(int, int)));
+    connect(this, TQ_SIGNAL(doubleClicked(int, int, int, const TQPoint&)),
+            TQ_SLOT(slotEditEntry(int, int)));
 
 }
 
