@@ -95,8 +95,8 @@ AudioFileManager::AudioFileManager() :
 
     // Retransmit progress
     //
-    connect(&m_peakManager, TQT_SIGNAL(setProgress(int)),
-            this, TQT_SIGNAL(setProgress(int)));
+    connect(&m_peakManager, TQ_SIGNAL(setProgress(int)),
+            this, TQ_SIGNAL(setProgress(int)));
 }
 
 AudioFileManager::~AudioFileManager()
@@ -414,7 +414,7 @@ AudioFileManager::setAudioPath(const std::string &path)
 }
 
 void
-AudioFileManager::testAudioPath() throw (BadAudioPathException)
+AudioFileManager::testAudioPath()
 {
     TQFileInfo info(m_audioPath.c_str());
     if (!(info.exists() && info.isDir() && !info.isRelative() &&
